==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/sound/translations/sound_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>@default</name>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Uyarılar</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Sound theme</source>
        <translation>Ses teması</translation>
    </message>
    <message>
        <source>Sound paths</source>
        <translation>Ses yolları</translation>
    </message>
    <message>
        <source>Test sound playing</source>
        <translation>Ses çalarak test edin</translation>
    </message>
    <message>
        <source>Play a sound</source>
        <translation>Bir ses çal</translation>
    </message>
    <message>
        <source>Enable sound notifications</source>
        <translation>Sesli uyarılar olsun</translation>
    </message>
</context>
<context>
    <name>SoundBuddyConfigurationWidget</name>
    <message>
        <source>Use custom sound</source>
        <translation>Özel ses kullan</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
</context>
<context>
    <name>SoundChatConfigurationWidget</name>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Use custom sound</source>
        <translation>Özel ses kullan</translation>
    </message>
</context>
<context>
    <name>SoundConfigurationUiHandler</name>
    <message>
        <source>Custom</source>
        <translation>Özel</translation>
    </message>
</context>
<context>
    <name>SoundMuteAction</name>
    <message>
        <source>Play Sounds</source>
        <translation>Sesleri Yürüt</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/sound/translations/sound_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Uyarılar</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Sound theme</source>
        <translation>Ses teması</translation>
    </message>
    <message>
        <source>Sound paths</source>
        <translation>Ses yolları</translation>
    </message>
    <message>
        <source>Test sound playing</source>
        <translation>Ses çalarak test edin</translation>
    </message>
    <message>
        <source>Play a sound</source>
        <translation>Bir ses çal</translation>
    </message>
    <message>
        <source>Enable sound notifications</source>
        <translation>Sesli uyarılar olsun</translation>
    </message>
</context>
<context>
    <name>SoundBuddyConfigurationWidget</name>
    <message>
        <source>Use custom sound</source>
        <translation>Özel ses kullan</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
</context>
<context>
    <name>SoundChatConfigurationWidget</name>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Use custom sound</source>
        <translation>Özel ses kullan</translation>
    </message>
</context>
<context>
    <name>SoundConfigurationUiHandler</name>
    <message>
        <source>Custom</source>
        <translation>Özel</translation>
    </message>
</context>
<context>
    <name>SoundMuteAction</name>
    <message>
        <source>Play Sounds</source>
        <translation>Sesleri Yürüt</translation>
    </message>
</context>
</TS>
